const express = require('express')
const router = express.Router()
const passport = require('passport')
const bodyParser = require('body-parser');
const cookieParser = require('cookie-parser');
const csrf = require('csurf')
// setup route middlewares
var csrfProtection = csrf({ cookie: true });
var parseForm = bodyParser.urlencoded({ extended: false });
router.use(cookieParser());

router.get('/', (req, res) => {
    if (req.isAuthenticated()) {
        res.render('private/priv1', {
            title: 'Home',
            user: req.user,
            message: res.locals.message
        })
    } else {
        res.render('login', {
            title: 'Home',
            user: req.user,
            message: res.locals.message
        })
    }
})

router.get('/login', csrfProtection, (req, res) => {
    if (req.isAuthenticated()) {
        req.flash('message', 'Your are already logged in.')
        res.redirect('/priv')
    } else {
        res.render('login', {
            title: 'Login',
            user: req.user,
			csrfToken: req.csrfToken(),
            message: res.locals.message
        })
    }
})
router.post('/login', parseForm, csrfProtection, (req, res, next) => {
    if (req.isAuthenticated()) {
        req.flash('message', 'You are already logged in.')
        res.redirect('/priv')
    } else {
        let user = (req.body.username)
        let pass = req.body.password
        if (user.length === 0 || pass.length === 0) {
            req.flash('message', 'You must provide a username and password.')
            res.redirect('/priv/login')
        } else {
            next()
        }
    }
}, passport.authenticate('pop3', {
    successRedirect : '/priv',
    failureRedirect : '/priv/login',
    failureFlash : true
}))

router.get('/logout', (req, res) => {
    if (req.isAuthenticated()) {
        console.log('User [' + req.user.username + '] has logged out.')
        req.logout()
        res.redirect('/');
    } else {
        res.redirect('/')
    }
})

router.get('/priv2', (req, res) => {
    if (req.isAuthenticated()) {
        res.render('private/priv2', {
            title: 'Private2',
            user: req.user,
            message: res.locals.message
        })
    } else {
        res.redirect('/')
    }
})

module.exports = router;